==> unicore-uvos-webapp-1.5.0-6.src.tar.gz: src/main/java/pl/edu/icm/uvos/webapp/data/DataStoreImpl.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Jan 28, 2008
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.uvos.webapp.data;

import java.util.List;

import org.picocontainer.PicoContainer;

import pl.edu.icm.unicore.uvos.api.VOApplication;
import pl.edu.icm.unicore.uvos.api.VOApplicationForm;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.SecurityException;
import pl.edu.icm.unicore.uvos.api.exceptions.VOApplicationException;
import pl.edu.icm.unicore.uvos.engine.api.VOApplicationInterface;

/**
 * @author K. Benedyczak
 */
public class DataStoreImpl implements DataStore
{
	private VOApplicationInterface voapps;
	
	public DataStoreImpl()
	{
		PicoContainer pico = PicoAccessor.getPico();
		if (pico == null)
			return;
		voapps = pico.getComponent(VOApplicationInterface.class);
	}
	
	public VOApplicationForm getApplicationFormById(int id) 
		throws SecurityException, InternalException
	{
		List<VOApplicationForm> all = getApplicationForms();
		for (VOApplicationForm f: all)
			if (f.getId() == id)
				return f;
		throw new InternalException("There is no form with id: " + id);
	}

	public List<VOApplicationForm> getApplicationForms() 
		throws SecurityException, InternalException
	{
		return voapps.getApplicationForms();
	}

	public void submitApplication(VOApplication application) 
		throws SecurityException, InternalException, VOApplicationException
	{
		voapps.submitApplication(application);
	}

}

==> unicore-uvos-webapp-1.6.0-0.src.tar.gz: src/main/java/pl/edu/icm/uvos/webapp/data/DataStoreImpl.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Jan 28, 2008
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.uvos.webapp.data;

import java.util.List;

import javax.servlet.ServletConfig;

import org.apache.log4j.Logger;
import org.picocontainer.PicoContainer;
import org.springframework.web.context.ServletConfigAware;

import eu.unicore.util.Log;

import pl.edu.icm.unicore.uvos.api.VOApplication;
import pl.edu.icm.unicore.uvos.api.VOApplicationForm;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.SecurityException;
import pl.edu.icm.unicore.uvos.api.exceptions.VOApplicationException;
import pl.edu.icm.unicore.uvos.engine.api.VOApplicationInterface;
import pl.edu.icm.unicore.uvos.server.JettyServer;

/**
 * @author K. Benedyczak
 */
public class DataStoreImpl implements DataStore, ServletConfigAware
{
	private static final Logger log = Log.getLogger(LogConfig.PFX, DataStoreImpl.class);
	private VOApplicationInterface voapps;

	@Override
	public void setServletConfig(ServletConfig srvCfg)
	{
		PicoContainer pico = (PicoContainer) srvCfg.getServletContext().getAttribute(JettyServer.UVOS_SERVER_CONTAINER_REFERENCE);
		if (pico == null) 
			log.fatal("Can't get PicoContainer from the servlet context. Either" +
				" you deployed this servlet to an other than UVOS container " +
				" or to UVOS server with version < 1.6.0");
		voapps = pico.getComponent(VOApplicationInterface.class);
	}
	
	@Override
	public VOApplicationForm getApplicationFormById(int id) 
		throws SecurityException, InternalException
	{
		List<VOApplicationForm> all = getApplicationForms();
		for (VOApplicationForm f: all)
			if (f.getId() == id)
				return f;
		throw new InternalException("There is no form with id: " + id);
	}

	@Override
	public List<VOApplicationForm> getApplicationForms() 
		throws SecurityException, InternalException
	{
		return voapps.getApplicationForms();
	}

	@Override
	public void submitApplication(VOApplication application) 
		throws SecurityException, InternalException, VOApplicationException
	{
		voapps.submitApplication(application);
	}
}
